@@ -113,6 +113,8 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
         self._aiohttp_session: aiohttp.ClientSession = aiohttp.ClientSession(timeout=self._timeout,
                                                                              connector=aiohttp.TCPConnector(verify_ssl=False))
 
+        self._api_version_getrec: int = 0
+
         self.refresh_base_url()
 
     def enable_https(self, enable: bool):
@@ -300,6 +302,10 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
         self._lease_time = None
         return False
 
+    @property
+    def api_version_getrec(self):
+        return self._api_version_getrec
+
     def clear_token(self):
         """Initialize the token and lease time."""
         self._token = None
@@ -404,6 +410,7 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                 "action": 1,
                 "param": {"User": {"userName": self._username}},
             },
+            {"cmd": "GetAiState", "action": 0, "param": {"channel": self._channel}},  # to capture AI capabilities
         ]
 
         response = await self.send(body)
@@ -536,6 +543,8 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
 
         push_data = None
         pushv20_data = None
+        rec_data = None
+        recv20_data = None
 
         for data in json_data:
             try:
@@ -543,10 +552,11 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                     continue
 
                 if data["cmd"] == "GetMdState":
-                    self._motion_state = json_data[0]["value"]["state"] == 1
+                    self._motion_state = data["value"]["state"] == 1
 
                 elif data["cmd"] == "GetAiState":
-                    self._ai_state = json_data[0]["value"]
+                    self._ai_state = data["value"]
+                    self._is_ia_enabled = True
 
                 elif data["cmd"] == "GetDevInfo":
                     self._device_info = data
@@ -557,8 +567,6 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                     self._channels = data["value"]["DevInfo"]["channelNum"]
                     self._sw_version_object = SoftwareVersion(self._sw_version)
                     self._is_nvr = data["value"]["DevInfo"].get("exactType", "CAM") == "NVR"
-                    if re.compile(r"^RLC-([0-9]+)A$").match(self._model) is not None:
-                        self._is_ia_enabled = True
 
                 elif data["cmd"] == "GetHddInfo":
                     self._hdd_info = data["value"]["HddInfo"]
@@ -610,15 +618,19 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
                     self._ir_state = data["value"]["IrLights"]["state"] == "Auto"
 
                 elif data["cmd"] == "GetRec":
-                    self._recording_settings = data
-                    self._recording_state = (
-                        data["value"]["Rec"]["schedule"]["enable"] == 1
-                    )
+                    if self._api_version_getrec <= 1:
+                        self._api_version_getrec = 1
+                        self._recording_settings = data
+                        self._recording_state = (
+                            data["value"]["Rec"]["schedule"]["enable"] == 1
+                        )
                 elif data["cmd"] == "GetRecV20":
-                    self._recording_settings = data
-                    self._recording_state = (
-                            data["value"]["Rec"]["enable"] == 1
-                    )
+                    if self._api_version_getrec <= 20:
+                        self._api_version_getrec = 20
+                        self._recording_settings = data
+                        self._recording_state = (
+                                data["value"]["Rec"]["enable"] == 1
+                        )
                 elif data["cmd"] == "GetPtzPreset":
                     self._ptz_presets_settings = data
                     for preset in data["value"]["PtzPreset"]:
@@ -883,11 +895,12 @@ class Api:  # pylint: disable=too-many-instance-attributes disable=too-many-publ
         else:
             new_value = 0
 
-        if self._recording_settings["value"]["Rec"].get("enable") is not None:
+        if self._api_version_getrec <= 1:
             body = [
                 {"cmd": "SetRecV20", "action": 0, "param": self._recording_settings["value"]}
             ]
             body[0]["param"]["Rec"]["enable"] = new_value
+
         else:
             body = [
                 {"cmd": "SetRec", "action": 0, "param": self._recording_settings["value"]}
